@@ -53,9 +53,12 @@ covHandling <- function(covData,
       # set up table and iterate across all combinations of parameters and covariates
       covTable <- data.frame()
       for(i in 1:length(covStructure)){
+        covStructure[[i]] <- gsub("\\,", " ",  gsub("~", ";", covStructure[[i]]))
         sss <- strsplit(covStructure[[i]], ";")[[1]]
-        if(length(sss) <2)
-          stop("Check predStructure (in one argument, a semicolon seems to be missing):\n",
+        if(length(sss)  != 2)
+          stop("Check predStructure: in each character argument of the list,\n",
+               "exactly one semicolon is required to separate parameters (left hand)\n",
+               "and predictors (right hand):\n",
                covStructure[[i]])
         pars <- strsplit(sss[1], " +")[[1]]
         covs <- strsplit(sss[2], " +")[[1]]
@@ -64,6 +67,11 @@ covHandling <- function(covData,
 
         # parameters:
         for(pp in 1:length(pars)){
+          if (!all(covs %in% colnames(covData)))
+            stop("Check names of predictors in predStructure. Valid names:\n    ",
+                  paste(colnames(covData), collapse = ", "), "\n",
+                 "Currently defined:\n    ",
+                 paste(covs, collapse = ", "), "\n")
           # covariates:
           for(cc in 1:length(covs)){
             covTable <- rbind(covTable, data.frame(Parameter = pars[pp], Covariate = covs[cc]))
